==> kadu_1.1.orig.tar.bz2: kadu-1.1/plugins/spellchecker/translations/spellchecker_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Großschreibung ignorieren</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Spelling</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation>Zu &apos;Überprüft&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation>Verfügbare Sprachen</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation>Zu &apos;Verfügbare Sprachen&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Überprüft</translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/spellchecker/translations/spellchecker_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Großschreibung ignorieren</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation>Zu &apos;Überprüft&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation>Verfügbare Sprachen</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation>Zu &apos;Verfügbare Sprachen&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Überprüft</translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
